from django.shortcuts import render
from rest_framework.views import APIView
from django.db.models.functions import Coalesce
from django.db.models import Sum
from django.utils import timezone
from rest_framework.response import Response
from rest_framework import status

from clmainApp.utils import getBranchId
from brvisitApp.models import PatientVisit,PvPayment
from brsessionApp.models import PatientSession,PtSsnPayment

# Create your views here.

class TotalIncomeTodayApi(APIView):

    def post(self,request):
        branchId = getBranchId(request)
        timezone_now_today = timezone.now().date()
        #timezone_now_today='2024-06-23'
        #get visits amounnt paid 
        visits_objs = PatientVisit.objects.filter(visit_day=timezone_now_today,visit_branch_id=branchId).aggregate(total_amount_paid=Coalesce(Sum('amount_paid'),0))
        total_visits_paid =visits_objs["total_amount_paid"]
        #get visits related payments 
        pv_related_payments_objs = PvPayment.objects.filter(created_at__date=timezone_now_today,pv__visit_branch_id=branchId).aggregate(total_related_payment=Coalesce(Sum('amount_paid'),0))
        pv_total_related_paid = pv_related_payments_objs["total_related_payment"]
        
        pv_total = int(total_visits_paid)+int(pv_total_related_paid)
        #get sessions initial amounnt paid 
        pt_sessions_objs = PatientSession.objects.filter(created_at__date=timezone_now_today,patient__branch_id=branchId).aggregate(total_initial_payment=Coalesce(Sum('initial_payment'),0))
        total_ssn_initial_payment = pt_sessions_objs["total_initial_payment"]
        #get sessions related amounnt paid 
        ssn_related_payments_objs = PtSsnPayment.objects.filter(created_at__date=timezone_now_today,pt_ssn__patient__branch_id=branchId).aggregate(total_related_payment=Coalesce(Sum('amount_paid'),0))
        ssn_related_payments_paid = ssn_related_payments_objs["total_related_payment"]
        
        ssn_total = int(total_ssn_initial_payment)+int(ssn_related_payments_paid)

        total_cash = pv_total+ssn_total
        response_data={"total_cash":total_cash,"pv_total":pv_total,"ssn_total":ssn_total, "today_server_date":str(timezone_now_today)}
        return Response(response_data,status=status.HTTP_200_OK)